@@ -3,7 +3,7 @@ import time
 import requests
 import LibHanger.Library.uwLogger as Logger
 from os import path
-from bs4 import BeautifulSoup
+from bs4 import BeautifulSoup, ResultSet, Tag
 from selenium.webdriver.common.by import By
 from selenium.webdriver.android.webdriver import WebDriver
 from pandas.core.frame import DataFrame
@@ -50,6 +50,29 @@ class baseWebBrowserController:
         
         return self.__loadPageCount
     
+    def getRow(self, row:ResultSet):
+            
+        """
+        レース結果テーブルの行情報をディクショナリに変換して取得する
+
+        Parameters
+        ----------
+            row : ResultSet
+                行情報
+        """
+        
+        # 行情報ディクショナリ初期化
+        dictRow = dict[int, Tag]()
+
+        # 行情報をディクショナリにセット
+        colIndex = 0
+        for data in row:
+            dictRow[colIndex] = data
+            colIndex += 1
+            
+        # 戻り値を返す
+        return dictRow
+    
     @Logger.loggerDecorator('Get WebDriverPath')
     def getWebDriverPath(self, _webDriverPath:scrapingConfig.settingValueStruct.WebDriverPath):
         
