@@ -4,6 +4,10 @@ class scrapingerGlobal(globalValues):
     
     def __init__(self):
         
+        """
+        コンストラクタ
+        """
+            
         # 基底側コンストラクタ呼び出し
         super().__init__()
         
