@@ -37,19 +37,22 @@ class webDriverController(baseWebBrowserController):
         # ブラウザーコントロールインスタンス初期化
         self.browserCtl = None
 
-    @Logger.loggerDecorator('Setting Scrape')    
+    @Logger.loggerDecorator('Setting Scrape')
     def settingScrape(self):
         
         """
         スクレイピング準備
         """
         
+        # 既にbrowserCtlインスタンスが存在する場合は処理を抜ける
+        if not self.browserCtl is None: return
+        
         if self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.beutifulSoup.value:
             self.getBeautifulSoupInstance()
         elif self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.selenium.value:
             self.getWebDriverInstance()
     
-    @Logger.loggerDecorator('Get BeautifulSoupInstance')    
+    @Logger.loggerDecorator('Get BeautifulSoupInstance')
     def getBeautifulSoupInstance(self):
         
         """
